==> kadu_1.0.orig.tar.bz2: kadu-1.0/plugins/history/translations/history_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Cronologia chat</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Salva i messaggi nella cronologia</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Salva le chat con utenti anonimi</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Cambiamenti stato</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Salva cambiamenti stato</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Salva cambiamenti di stato nella cronologia</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Salva solo stati con la descrizione</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Visualizza cronologia</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>History in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>yesterday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>last week</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>last month</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Conservazione</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Cronologia Chat</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Pulisci Cronologia Chat</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Pulisci cronologia</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Rimuovi ingressi</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lunghezza</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Pulisci Cronologia Stati</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Pulisci Cronologia Messaggi(sms)</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> - All chats - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Smses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>By date</source>
        <translation>Per data</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buddy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Visualizza cronologia chat</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Visualizza l&apos;ultimo %1 messaggi</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Visualizza messaggi da ieri</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Visualizza messaggi degli ultimi 7 giorni</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Visualizza messaggi degli ultimi 30 giorni</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Visualizza tutta la cronologia</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/history/translations/history_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Cronologia chat</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Salva i messaggi nella cronologia</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Salva le chat con utenti anonimi</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Cambiamenti stato</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Salva cambiamenti stato</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Salva cambiamenti di stato nella cronologia</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Salva solo stati con la descrizione</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Visualizza cronologia</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>last week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>last month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Conservazione</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Cronologia Chat</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Pulisci Cronologia Chat</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Pulisci cronologia</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Rimuovi ingressi</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lunghezza</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Pulisci Cronologia Stati</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Pulisci Cronologia Messaggi(sms)</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Per data</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">Cerca</translation>
    </message>
    <message>
        <source>Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished">Chat</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Visualizza cronologia chat</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Visualizza l&apos;ultimo %1 messaggi</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Visualizza messaggi da ieri</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Visualizza messaggi degli ultimi 7 giorni</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Visualizza messaggi degli ultimi 30 giorni</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Visualizza tutta la cronologia</translation>
    </message>
</context>
</TS>
